@@ -27,9 +27,8 @@ ${DISTRIBUTION}-backports repository"
     CHANGELOG_INTROLINE="Changes since the previous backported version in ${DISTRIBUTION}:"
     CHANGELOG_BACKPORT="
 Differences from testing package ($TESTING_VERSION):
-  * d/control,rules: remove doc package because of missing dependencies
-    on ${DISTRIBUTION}.
-  * d/patches: fix tests with exceptiongroup v1.1.0.
+  * d/patches: reintroduce pytest 7 patch to add missing
+    ExceptionInfo.group_contains method.
 
 "
     PACKAGES_LIST="
